#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmcon import ResourceConfig

class Wifi(BaseObject):
    """
    
    """

    __config = {
        
        "3f47915b-73eb-4a83-8899-c0fbc27da486" : OperationConfig("/loyalty/v1/users/{userId}/wifi", "query", ["x-client-correlation-id"], []),
        
        "0c6cb9ee-c019-4db9-b613-03daf57e572f" : OperationConfig("/loyalty/v1/wifi", "query", ["x-client-correlation-id"], ["latitude","longitude","radius"]),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())







    @classmethod
    def userWifiRegistrationStatus(cls,criteria):
        """
        Query objects of type Wifi by id and optional criteria
        @param type criteria
        @return Wifi object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("3f47915b-73eb-4a83-8899-c0fbc27da486", Wifi(criteria))






    @classmethod
    def getWifi(cls,criteria):
        """
        Query objects of type Wifi by id and optional criteria
        @param type criteria
        @return Wifi object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("0c6cb9ee-c019-4db9-b613-03daf57e572f", Wifi(criteria))





#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmcon import ResourceConfig

class Offers(BaseObject):
    """
    
    """

    __config = {
        
        "7b1ba8b8-85b5-42b1-8fa6-a8ac6dbb192b" : OperationConfig("/loyalty/v1/offers", "query", ["x-client-correlation-id"], ["userId","preferredLanguage","sort","category","featured","favorite","partner"]),
        
        "460eee16-ed13-4b7a-8233-90071ca4399f" : OperationConfig("/loyalty/v1/offers/{offerId}/activate", "create", ["x-client-correlation-id"], []),
        
        "514d3dc4-18b2-44d5-acf3-d3de5b64025a" : OperationConfig("/loyalty/v1/offers/{offerId}/detail", "query", ["x-client-correlation-id"], ["userId","preferredLanguage"]),
        
        "9aa4381f-0ab0-4fd1-a028-2a28ae33fea5" : OperationConfig("/loyalty/v1/offers/{offerId}/favorite", "create", ["x-client-correlation-id"], []),
        
        "85b85152-da21-49d2-b14b-7de09f516f18" : OperationConfig("/loyalty/v1/offers/{offerId}/redeem", "create", ["x-client-correlation-id"], []),
        
        "65c13d14-4f92-4fb8-8dc9-1111001babe3" : OperationConfig("/loyalty/v1/offers/{offerId}/unfavorite", "create", ["x-client-correlation-id"], []),
        
        "c00a90b1-11c0-4ca0-b881-19db5e6960d0" : OperationConfig("/loyalty/v1/offers/promo", "create", ["x-client-correlation-id"], []),
        
        "1c6237dd-90cd-4aab-99ce-7a1f70f09f35" : OperationConfig("/loyalty/v1/offers/redeemed", "query", ["x-client-correlation-id"], ["userId","preferredLanguage"]),
        
        "54105f1e-6ff8-4cad-ae83-f0d94c826260" : OperationConfig("/loyalty/v1/points/expiring", "query", ["x-client-correlation-id"], ["userId"]),
        
        "9e90450d-9cc3-494c-b032-44f9e89867a9" : OperationConfig("/loyalty/v1/points", "query", ["x-client-correlation-id"], ["userId"]),
        
        "6a36e267-29bf-4c34-892f-7d34764d5030" : OperationConfig("/loyalty/v1/users/{userId}/offers", "query", ["x-client-correlation-id"], []),
        
        "15ff4c59-a170-4259-9452-56a65ed80662" : OperationConfig("/loyalty/v1/vouchers", "query", ["x-client-correlation-id"], ["userId"]),
        
        "51aef484-282f-42fe-8dd7-822ac7da5c6f" : OperationConfig("/loyalty/v1/vouchers/{voucherId}/detail", "query", ["x-client-correlation-id"], ["userId"]),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())







    @classmethod
    def getOffers(cls,criteria):
        """
        Query objects of type Offers by id and optional criteria
        @param type criteria
        @return Offers object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("7b1ba8b8-85b5-42b1-8fa6-a8ac6dbb192b", Offers(criteria))

    @classmethod
    def activateOffer(cls,mapObj):
        """
        Creates object of type Offers

        @param Dict mapObj, containing the required parameters to create a new object
        @return Offers of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("460eee16-ed13-4b7a-8233-90071ca4399f", Offers(mapObj))











    @classmethod
    def getOfferDetail(cls,criteria):
        """
        Query objects of type Offers by id and optional criteria
        @param type criteria
        @return Offers object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("514d3dc4-18b2-44d5-acf3-d3de5b64025a", Offers(criteria))

    @classmethod
    def favoriteOffer(cls,mapObj):
        """
        Creates object of type Offers

        @param Dict mapObj, containing the required parameters to create a new object
        @return Offers of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("9aa4381f-0ab0-4fd1-a028-2a28ae33fea5", Offers(mapObj))






    @classmethod
    def redeemOffer(cls,mapObj):
        """
        Creates object of type Offers

        @param Dict mapObj, containing the required parameters to create a new object
        @return Offers of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("85b85152-da21-49d2-b14b-7de09f516f18", Offers(mapObj))






    @classmethod
    def unfavoriteOffer(cls,mapObj):
        """
        Creates object of type Offers

        @param Dict mapObj, containing the required parameters to create a new object
        @return Offers of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("65c13d14-4f92-4fb8-8dc9-1111001babe3", Offers(mapObj))






    @classmethod
    def submitOfferPromo(cls,mapObj):
        """
        Creates object of type Offers

        @param Dict mapObj, containing the required parameters to create a new object
        @return Offers of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("c00a90b1-11c0-4ca0-b881-19db5e6960d0", Offers(mapObj))











    @classmethod
    def getRedeemedOffers(cls,criteria):
        """
        Query objects of type Offers by id and optional criteria
        @param type criteria
        @return Offers object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("1c6237dd-90cd-4aab-99ce-7a1f70f09f35", Offers(criteria))






    @classmethod
    def getPointsExpiring(cls,criteria):
        """
        Query objects of type Offers by id and optional criteria
        @param type criteria
        @return Offers object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("54105f1e-6ff8-4cad-ae83-f0d94c826260", Offers(criteria))






    @classmethod
    def getPoints(cls,criteria):
        """
        Query objects of type Offers by id and optional criteria
        @param type criteria
        @return Offers object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("9e90450d-9cc3-494c-b032-44f9e89867a9", Offers(criteria))






    @classmethod
    def userOffersRegistrationStatus(cls,criteria):
        """
        Query objects of type Offers by id and optional criteria
        @param type criteria
        @return Offers object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("6a36e267-29bf-4c34-892f-7d34764d5030", Offers(criteria))






    @classmethod
    def getVouchers(cls,criteria):
        """
        Query objects of type Offers by id and optional criteria
        @param type criteria
        @return Offers object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("15ff4c59-a170-4259-9452-56a65ed80662", Offers(criteria))






    @classmethod
    def getVoucherDetail(cls,criteria):
        """
        Query objects of type Offers by id and optional criteria
        @param type criteria
        @return Offers object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("51aef484-282f-42fe-8dd7-822ac7da5c6f", Offers(criteria))





#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmcon import ResourceConfig

class Airport(BaseObject):
    """
    
    """

    __config = {
        
        "0c72bbb0-059a-4074-ae10-39c353557bcf" : OperationConfig("/loyalty/v1/airport/dmc", "query", ["x-client-correlation-id"], ["userId","panLastFourDigits"]),
        
        "6a380410-f67b-465e-851e-6f7aad1c5c43" : OperationConfig("/loyalty/v1/airport/history", "query", ["x-client-correlation-id"], ["userId","panLastFourDigits","preferredLanguage","transactionDateFrom","transactionDateTo"]),
        
        "00612ed1-afe2-45fd-ad97-dcde2e161379" : OperationConfig("/loyalty/v1/airport/lounges", "query", ["x-client-correlation-id"], ["userId","panLastFourDigits","searchText","preferredLanguage"]),
        
        "22d3b6c0-6b89-4a7e-bc11-fdbf1d112146" : OperationConfig("/loyalty/v1/airport/lounges/{loungeCode}/detail", "query", ["x-client-correlation-id"], ["userId","panLastFourDigits","preferredLanguage"]),
        
        "b68a1cce-baea-4265-bb9e-11da557e71a5" : OperationConfig("/loyalty/v1/users/{userId}/airport", "query", ["x-client-correlation-id"], ["panLastFourDigits"]),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())







    @classmethod
    def getDMC(cls,criteria):
        """
        Query objects of type Airport by id and optional criteria
        @param type criteria
        @return Airport object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("0c72bbb0-059a-4074-ae10-39c353557bcf", Airport(criteria))






    @classmethod
    def getLoungeHistory(cls,criteria):
        """
        Query objects of type Airport by id and optional criteria
        @param type criteria
        @return Airport object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("6a380410-f67b-465e-851e-6f7aad1c5c43", Airport(criteria))






    @classmethod
    def getLounges(cls,criteria):
        """
        Query objects of type Airport by id and optional criteria
        @param type criteria
        @return Airport object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("00612ed1-afe2-45fd-ad97-dcde2e161379", Airport(criteria))






    @classmethod
    def getLoungeDetail(cls,criteria):
        """
        Query objects of type Airport by id and optional criteria
        @param type criteria
        @return Airport object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("22d3b6c0-6b89-4a7e-bc11-fdbf1d112146", Airport(criteria))






    @classmethod
    def userAirportRegistrationStatus(cls,criteria):
        """
        Query objects of type Airport by id and optional criteria
        @param type criteria
        @return Airport object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("b68a1cce-baea-4265-bb9e-11da557e71a5", Airport(criteria))





from mastercardapicore import *

# import apis resourceconfig
from mastercardmcon.resourceconfig import ResourceConfig


# import apis into api package
from mastercardmcon.airport import *
from mastercardmcon.benefits import *
from mastercardmcon.bundleprofile import *
from mastercardmcon.insurance import *
from mastercardmcon.offers import *
from mastercardmcon.wifi import *



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmcon import ResourceConfig

class BundleProfile(BaseObject):
    """
    
    """

    __config = {
        
        "5d7dd404-85b1-481f-ad2c-afb395dcf18c" : OperationConfig("/bundle/profile/v1/users", "create", ["x-client-correlation-id"], []),
        
        "6da189ef-7300-47aa-959c-a2150b20f2cb" : OperationConfig("/bundle/profile/v1/users/{userId}", "delete", ["x-client-correlation-id"], []),
        
        "1c9b5edb-46bc-40cd-90c8-5721c673bcbf" : OperationConfig("/bundle/profile/v1/users/{userId}/patch", "create", ["x-client-correlation-id"], []),
        
        "15fa34d5-0539-4447-b3d9-73ae78749d99" : OperationConfig("/bundle/profile/v1/users/{userId}", "read", ["x-client-correlation-id"], []),
        
        "1ff90686-79b9-4d1c-bef9-614fc0528667" : OperationConfig("/bundle/profile/v1/users/{userId}", "update", ["x-client-correlation-id"], []),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


    @classmethod
    def createUser(cls,mapObj):
        """
        Creates object of type BundleProfile

        @param Dict mapObj, containing the required parameters to create a new object
        @return BundleProfile of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("5d7dd404-85b1-481f-ad2c-afb395dcf18c", BundleProfile(mapObj))









    @classmethod
    def deleteUserById(cls,id,map=None):
        """
        Delete object of type BundleProfile by id

        @param str id
        @return BundleProfile of the response of the deleted instance.
        @raise ApiException: raised an exception from the response status
        """

        mapObj =  RequestMap()
        if id:
            mapObj.set("id", id)

        if map:
            if (isinstance(map,RequestMap)):
                mapObj.setAll(map.getObject())
            else:
                mapObj.setAll(map)

        return BaseObject.execute("6da189ef-7300-47aa-959c-a2150b20f2cb", BundleProfile(mapObj))

    def deleteUser(self):
        """
        Delete object of type BundleProfile

        @return BundleProfile of the response of the deleted instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("6da189ef-7300-47aa-959c-a2150b20f2cb", self)



    @classmethod
    def patchUser(cls,mapObj):
        """
        Creates object of type BundleProfile

        @param Dict mapObj, containing the required parameters to create a new object
        @return BundleProfile of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("1c9b5edb-46bc-40cd-90c8-5721c673bcbf", BundleProfile(mapObj))










    @classmethod
    def readUser(cls,id,criteria=None):
        """
        Returns objects of type BundleProfile by id and optional criteria
        @param str id
        @param dict criteria
        @return instance of BundleProfile
        @raise ApiException: raised an exception from the response status
        """
        mapObj =  RequestMap()
        if id:
            mapObj.set("id", id)

        if criteria:
            if (isinstance(criteria,RequestMap)):
                mapObj.setAll(criteria.getObject())
            else:
                mapObj.setAll(criteria)

        return BaseObject.execute("15fa34d5-0539-4447-b3d9-73ae78749d99", BundleProfile(mapObj))



    def updateUser(self):
        """
        Updates an object of type BundleProfile

        @return BundleProfile object representing the response.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("1ff90686-79b9-4d1c-bef9-614fc0528667", self)






